from .emaileasily import email_attach_document
from .emaileasily import email_bcc
from .emaileasily import email_cc
from .emaileasily import email_content
from .emaileasily import email_html
from .emaileasily import email_send
from .emaileasily import email_subject
from .emaileasily import email_to
from .emaileasily import get_multipart_email
from .emaileasily import get_non_multipart_emails
from .emaileasily import get_subject_and_from
from .emaileasily import name_folder
from .emaileasily import read_emails
from .emaileasily import get_attachments
from .emaileasily import get_html_emails
from .emaileasily import close_imap
from .emaileasily import loop_through_addresses

__version__ = '0.1.2'
